@@ -12,5 +12,5 @@ class GrammarBase:
 
 def set_rules(grammar):
     for rule_text, actions in grammar.mapping.items():
-        rule = ruleparser.Rule(rule_text, grammar.dictionary, actions)
+        rule = ruleparser.Rule(rule_text, grammar.dictionary, actions, grammar)
         grammar.rules.append(rule)
\ No newline at end of file
